@@ -1,11 +1,11 @@
-use std::io::{Error, ErrorKind, Result};
-
 use serde::*;
 use serde_json::to_vec_pretty;
 
 use super::Exporter;
-use crate::benchmark_result::BenchmarkResult;
-use crate::units::Unit;
+use crate::benchmark::benchmark_result::BenchmarkResult;
+use crate::util::units::Unit;
+
+use anyhow::Result;
 
 #[derive(Serialize, Debug)]
 struct HyperfineSummary<'a> {
@@ -18,10 +18,10 @@ pub struct JsonExporter {}
 impl Exporter for JsonExporter {
     fn serialize(&self, results: &[BenchmarkResult], _unit: Option<Unit>) -> Result<Vec<u8>> {
         let mut output = to_vec_pretty(&HyperfineSummary { results });
-        for content in output.iter_mut() {
+        if let Ok(ref mut content) = output {
             content.push(b'\n');
         }
 
-        output.map_err(|e| Error::new(ErrorKind::Other, e))
+        Ok(output?)
     }
 }
